==> bellsoft-jdk21.0.9+11-src-full.tar.gz: jdk-21.0.9-full/openjfx/modules/javafx.controls/src/shims/java/javafx/scene/control/skin/TableHeaderRowShim.java <==
/*
 * Copyright (c) 2015, 2023 Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package javafx.scene.control.skin;

import javafx.scene.control.ContextMenu;
import javafx.scene.layout.Pane;
import javafx.scene.control.TableColumnBase;

public class TableHeaderRowShim {

    public static TableColumnHeader getColumnHeaderFor(TableHeaderRow tr, final TableColumnBase<?,?> col) {
        return tr.getColumnHeaderFor(col);
    }

    public static ContextMenu getColumnPopupMenu(TableHeaderRow tableHeaderRow) {
        return tableHeaderRow.getColumnPopupMenu();
    }

    public static Pane getCornerRegion(TableHeaderRow tableHeaderRow) {
        return tableHeaderRow.getCornerRegion();
    }
}

==> bellsoft-jdk25.0.2+12-src-full.tar.gz: jdk-25.0.2-full/openjfx/modules/javafx.controls/src/shims/java/javafx/scene/control/skin/TableHeaderRowShim.java <==
/*
 * Copyright (c) 2015, 2023 Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package javafx.scene.control.skin;

import javafx.scene.control.ContextMenu;
import javafx.scene.layout.Pane;
import javafx.scene.control.TableColumnBase;

public class TableHeaderRowShim {

    public static TableColumnHeader getColumnHeaderFor(TableHeaderRow tr, final TableColumnBase<?,?> col) {
        return tr.getColumnHeaderFor(col);
    }

    public static ContextMenu getColumnPopupMenu(TableHeaderRow tableHeaderRow) {
        return tableHeaderRow.getColumnPopupMenu();
    }

    public static Pane getCornerRegion(TableHeaderRow tableHeaderRow) {
        return tableHeaderRow.getCornerRegion();
    }

    public static void setReorderingColumn(TableHeaderRow tableHeaderRow, TableColumnBase<?, ?> tableColumnBase) {
        tableHeaderRow.setReorderingColumn(tableColumnBase);
    }

    public static void setReorderingRegion(TableHeaderRow tableHeaderRow, TableColumnHeader tableColumnHeader) {
        tableHeaderRow.setReorderingRegion(tableColumnHeader);
    }
}
